/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.samples;

import java.text.MessageFormat;

import org.apache.log4j.Logger;
import org.apache.xmlbeans.XmlObject;
import org.ggf.schemas.jsdl.x2005.x11.jsdl.ExactType;
import org.ggf.schemas.jsdl.x2005.x11.jsdl.JobDefinitionDocument;
import org.ggf.schemas.jsdl.x2005.x11.jsdl.JobDefinitionType;
import org.ogf.graap.wsag.server.monitoring.IMonitoringContext;
import org.ogf.graap.wsag.server.monitoring.IServiceTermMonitoringHandler;
import org.ogf.schemas.graap.wsAgreement.ServiceTermStateDefinition;
import org.ogf.schemas.graap.wsAgreement.ServiceTermStateType;
import org.w3c.dom.Node;

/**
 * SampleServiceTermMonitor
 * 
 * @author hrasheed
 * 
 */
public class SampleServiceTermMonitor implements IServiceTermMonitoringHandler
{

    private static final Logger LOG = Logger.getLogger( SampleServiceTermMonitor.class );

    /**
     * {@inheritDoc}
     */
    public void monitor( IMonitoringContext context ) throws Exception
    {

        try
        {

            ServiceTermStateType sampleServiceTerm = context.getServiceTermStateByName( "SAMPLE1_SDT" );

            JobDefinitionType sampleJob = loadJobDefinition( sampleServiceTerm );
            sampleJob.getJobDescription().addNewResources().addNewCandidateHosts().addHostName( "target_host" );
            ExactType[] exactCPUs = new ExactType[0];
            exactCPUs[0].setDoubleValue( 2.0 );
            sampleJob.getJobDescription().getResources().addNewIndividualCPUCount().setExactArray( exactCPUs );

            sampleServiceTerm.setState( ServiceTermStateDefinition.COMPLETED );

        }
        catch ( Exception e )
        {
            String message =
                MessageFormat.format( "Failed to update service term state. Reason: {0}",
                                      new Object[] { e.getMessage() } );
            LOG.error( message );
            throw new Exception( message, e );
        }
    }

    private synchronized JobDefinitionType loadJobDefinition( ServiceTermStateType state )
    {

        XmlObject[] jobDefinition =
            state.selectChildren( JobDefinitionDocument.type.getDocumentElementName() );

        if ( jobDefinition.length == 0 )
        {
            LOG.trace( "Initialize job definition in service term state." );

            JobDefinitionDocument jobdef = JobDefinitionDocument.Factory.newInstance();
            jobdef.addNewJobDefinition().addNewJobDescription();

            Node imported =
                state.getDomNode().getOwnerDocument().importNode( jobdef.getJobDefinition().getDomNode(),
                                                                  true );
            state.getDomNode().appendChild( imported );

            jobDefinition = state.selectChildren( JobDefinitionDocument.type.getDocumentElementName() );
        }

        if ( jobDefinition.length > 1 )
        {
            String msgDebug =
                "Multiple job definitions founds in service term state. "
                    + "Keeping the first, removing the others.";
            LOG.debug( msgDebug );

            for ( int i = 1; i < jobDefinition.length; i++ )
            {
                state.getDomNode().removeChild( jobDefinition[i].getDomNode() );
            }

            jobDefinition = state.selectChildren( JobDefinitionDocument.type.getDocumentElementName() );
        }

        JobDefinitionType result = (JobDefinitionType) jobDefinition[0];

        return result;
    }

}
