/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.samples.actions;

import org.ggf.schemas.jsdl.x2005.x11.jsdl.ResourcesType;
import org.ogf.graap.wsag.api.pattern.AdvanceReservationPattern;
import org.ogf.graap.wsag.api.pattern.ComputeResourcePattern;
import org.ogf.graap.wsag.api.types.AgreementOfferType;
import org.ogf.graap.wsag4j.types.scheduling.TimeConstraintType;
import org.ogf.schemas.graap.wsAgreement.AgreementTemplateType;
import org.ogf.schemas.graap.wsAgreement.AgreementType;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationOfferType;

/**
 * SampleNegotiationAgreementOffer
 * 
 * @author hrasheed
 * 
 */
public class SampleAgreementOffer extends AgreementOfferType
{

    private ComputeResourcePattern resourcePattern = null;

    private AdvanceReservationPattern arPattern = null;

    /**
     * Creates a SampleNegotiationAgreementOffer from a template.
     * 
     * @param template
     *            the XML representation of the template
     */
    public SampleAgreementOffer( AgreementTemplateType template )
    {
        super( template );
        initialize();
    }

    /**
     * Creates a SampleNegotiationAgreementOffer from a negotiation offer.
     * 
     * @param negotiationOffer
     *            the XML representation of the negotiation offer
     */
    public SampleAgreementOffer( NegotiationOfferType negotiationOffer )
    {
        super( negotiationOffer );
        initialize();
    }

    /**
     * Creates a SampleNegotiationAgreementOffer from a offer.
     * 
     * @param offer
     *            the XML representation of the negotiation offer
     */
    public SampleAgreementOffer( AgreementType offer )
    {
        super( offer );
        initialize();
    }

    private void initialize()
    {
        AgreementType offer = getXMLObject();
        resourcePattern = new ComputeResourcePattern( offer.getTerms().getAll() );
        arPattern = new AdvanceReservationPattern( offer.getTerms().getAll() );
    }

    /**
     * @return the resource definition
     * @see ComputeResourcePattern#getResourceDefinition()
     */
    public ResourcesType getResourceDefinition()
    {
        return resourcePattern.getResourceDefinition();
    }

    /**
     * @return the specified time constraints
     * 
     * @see AdvanceReservationPattern#getTimeConstraint()
     */
    public TimeConstraintType getTimeConstraint()
    {
        return arPattern.getTimeConstraint();
    }
}
