/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.samples.site;

import org.ggf.schemas.jsdl.x2005.x11.jsdl.JobDefinitionType;

/**
 * Example for a service implementation. The example service is instantiated for a specific JSDL job. After it
 * was instantiated, the service can be started and stopped. As long as the service runs, it prints the job
 * properties to the console once a second.
 * 
 * @author owaeld
 * 
 */
public class ExampleService extends Thread
{

    private JobDefinitionType job;

    /**
     * Instantiates the example service with a given job.
     * 
     * @param job
     *            the job to execute
     */
    public ExampleService( JobDefinitionType job )
    {
        this.job = job;
    }

    /**
     * As long as the service runs, it prints the job properties to the console once a second.
     */
    @Override
    public void run()
    {
        while ( !isInterrupted() )
        {

            System.out.println( job.xmlText() );

            try
            {
                sleep( 1000 );
            }
            catch ( InterruptedException e )
            {
                // do nothing here
            }
        }
    }
}
